@@ -93,6 +93,12 @@ c----------------------------------------------------------------------
          t = tin
          return   !   **************
       endif
+      if( tin .eq. 0.) then
+         leng=0.
+         jcut = 0
+         t = tin
+         return  ! *********
+      endif
 
       if(UseTbl .and. z .lt. Htop ) then
          maxact = 100.d3
@@ -198,5 +204,9 @@ c                  get new s
          endif
          leng = s
       endif
+c  &&&&&&&&&
+      if(leng .le. 0.) then
+         rho = cvh2den(z)
+         leng =t / rho
+      endif
       end
-
