@@ -14,7 +14,7 @@ c
         integer k
 c
 
-        character*80 msg
+        character*100 msg
 
 
 
@@ -41,14 +41,17 @@ c
                call cpbarpXsec(ke, xs)
             endif
          elseif(k .eq. krho  .or. k .eq. komega  
-     *         .or. k .eq. kphi) then
+     *         .or. k .eq. kphi  .or. k .eq. kdmes) then
             if(pj.charge .ge. 0) then
                call cpiPluspXsec(ke, xs)
             else
                call cpiMinuspXsec(ke, xs)
             endif
+         elseif( k .ge. klambda .and. k .le. kbomega) then
+            call cppXsec(ke, xs)
          else
-               write(msg,*) ' undef.ptcl for csampCollInA=', k
+               write(msg,*) ' undef.ptcl for cxpXsec=', k,
+     *         ' K.E=', ke
                call cerrorMsg(msg, 0)
          endif
         end
