@@ -150,6 +150,8 @@ c
       integer i, now(2)
 #if defined Solaris
       integer time
+#elif defined PCLinuxIFC
+      integer hour, mint, sec, hsec
 #endif
 
 c  
@@ -182,6 +184,10 @@ c      *****************
       elseif(.not. RefreshIR .and. InitRN(2) .lt. 0) then
 #if defined Solaris
          now(1)= time()
+#elif defined PCLinuxIFC
+         call gettim(hour, mint, sec, hsec)
+         now(1) = hsec
+         now(2) = sec
 #else
          call time(now)
 #endif
