@@ -23,8 +23,13 @@ c
      *        IntInfArray(ProcessNo).process, ' undef'
               call cerrorMsg(msg, 0)
          endif
-         end
 
+         end
+c
+c         Pwork assumes that higher energy particles are normally
+c         in the last part, and stacked later from the last to
+c         save the stack area.  Due to this fact, putting ptlcs
+c         in Pwork must be reversed (realized from v6.10)
 c        *****************
          subroutine cbrems
 c        *****************
@@ -36,6 +41,7 @@ c        *****************
 #include  "Ztrackv.h"
 
          real*8 beg, den, cvh2den 
+         record /track/ aTrack
 
 c           get brem gamma energy
          if(LpmEffect .and. 
@@ -46,19 +52,22 @@ c            den = cthick2den(TrackBefMove.pos.depth)
          else
             call cbremsEnergy(MovedTrack.p.fm.p(4), beg)
          endif
-c           stack electron
-         MovedTrack.p.fm.p(4) = MovedTrack.p.fm.p(4) -beg
-         call ce2p(MovedTrack)
-         Nproduced = Nproduced + 1
-         Pwork(Nproduced) = MovedTrack.p
-c         call cpush(MovedTrack)
-c           stack gamma
-         MovedTrack.p.fm.p(4) = beg
-         call cmkptc(kphoton,  kcasg, 0,  MovedTrack.p)
-         call ce2p(MovedTrack)
-         Nproduced = Nproduced + 1
-         Pwork(Nproduced) = MovedTrack.p
-c         call cpush(MovedTrack)
+
+         aTrack = MovedTrack
+
+c         
+         aTrack.p.fm.p(4) = MovedTrack.p.fm.p(4) -beg
+         call ce2p(aTrack)
+c
+c         see           !! note above
+         Pwork(Nproduced+2) = aTrack.p
+
+         aTrack.p.fm.p(4) = beg
+         call cmkptc(kphoton,  kcasg, 0,  aTrack.p)
+         call ce2p(aTrack)
+         Pwork(Nproduced+1) = aTrack.p
+
+         Nproduced = Nproduced + 2
          end
 c      *****************
        subroutine cknockon(cg)
@@ -102,9 +111,8 @@ c           convert angle
        aTrack.p.fm.p(4) = e1
        call csetDirCos(dc1, aTrack)
        call ce2p(aTrack)
-       Nproduced = Nproduced + 1
-       Pwork(Nproduced) = aTrack.p
-c       call cpush(aTrack)
+
+       Pwork(Nproduced + 2) = aTrack.p
 c            knock on electron
        tmp=1.d0-cosr*cosr
        if(tmp .lt. 0.d0) then
@@ -116,17 +124,18 @@ c            knock on electron
        dc.r(2) = -sn*sinr
        dc.r(3) = cosr
        call ctransVectZ(MovedTrack.vec.w, dc, dcr)
-       MovedTrack.p.fm.p(4) = er
-       call csetDirCos(dcr, MovedTrack)
+       aTrack.p.fm.p(4) = er
+       call csetDirCos(dcr, aTrack)
 c
        if(cg .eq. 1) then
-          call cmkptc(kelec,  0,  -1,  MovedTrack.p)
+          call cmkptc(kelec,  0,  -1,  aTrack.p)
        endif
 
-       call ce2p(MovedTrack)
-       Nproduced = Nproduced + 1
-       Pwork(Nproduced) = MovedTrack.p
-c       call cpush(MovedTrack)
+       call ce2p(aTrack)
+
+       Pwork(Nproduced + 1) = aTrack.p
+
+       Nproduced = Nproduced + 2
       end
 c     *****************
       subroutine canihi
@@ -195,25 +204,23 @@ c        *****************
 
          real*8 x, beg
 
+         record /track/ aTrack
+
 c           get brem gamma energy
          call cmBremE(Upsilon, x) 
          beg = x * MovedTrack.p.fm.p(4)  ! gamma energy
-c           stack electron (note: in larger address than gamma
-c                 to save stack area later)
-         MovedTrack.p.fm.p(4) = MovedTrack.p.fm.p(4) -beg
-         call ce2p(MovedTrack)
-         Nproduced = Nproduced + 1
-         Pwork(Nproduced+1) = MovedTrack.p   !  NOte +1
 
+         aTrack = MovedTrack
+         aTrack.p.fm.p(4) = MovedTrack.p.fm.p(4) -beg
+         call ce2p(aTrack)
+         Pwork( Nproduced + 2 ) = aTrack.p   
 c           stack gamma (probably lower energy than e)
-         MovedTrack.p.fm.p(4) = beg
-         call cmkptc(kphoton,  kcasg, 0,  MovedTrack.p)
-         call ce2p(MovedTrack)
-         Pwork(Nproduced) = MovedTrack.p
-         Nproduced = Nproduced + 1         !  this should come here
+         aTrack.p.fm.p(4) = beg
+         call cmkptc(kphoton,  kcasg, 0,  aTrack.p)
+         call ce2p(aTrack)
+         Pwork(Nproduced + 1) = aTrack.p
+
+         Nproduced = Nproduced + 2         
          end
 
 
-
-
-
