@@ -107,20 +107,13 @@ c     ********************
 #include  "Ztrackv.h"
 #include  "Ztrackp.h"
 #include  "Zevhnp.h"
+#include  "Zevhnv.h"
 c
       character*70 msg
 
       if(IntInfArray(ProcessNo).process .eq. 'coll') then
-         if(IntModel .eq. 'int2' .and. 
-     *      (MovedTrack.p.code .eq. ktriton .or. 
-     *      MovedTrack.p.code .eq. kdeut) ) then
-c               gheisha should be used.
-            call chAcol(MovedTrack.p, TargetNucleonNo, TargetProtonNo,
-     *      Pwork, Nproduced)
-         else
-            call cheavyInt(MovedTrack.p, TargetNucleonNo,
+         call cheavyInt(MovedTrack.p, TargetNucleonNo,
      *         TargetProtonNo,  Pwork, Nproduced)
-         endif
       else
          write(msg, *) ' in cinteHeavy: process=',
      *           IntInfArray(ProcessNo).process,
@@ -274,6 +267,22 @@ c
      *     Pwork, Nproduced)
       endif
       end
+c     ********************
+      subroutine cinteBomega
+c     *****************
+      implicit none
+      
+#include  "Ztrack.h"
+#include  "Ztrackv.h"
+c
+
+      if(IntInfArray(ProcessNo).process .eq. 'decay') then
+         call cbomegaDcy(MovedTrack.p,  Pwork, Nproduced)
+      else
+         call chAcol(MovedTrack.p, TargetNucleonNo, TargetProtonNo,
+     *     Pwork, Nproduced)
+      endif
+      end
 c     *******************
       subroutine cinteEta
 c     *****************
@@ -301,7 +310,7 @@ c
       character*80 msg
 
       if(IntInfArray(ProcessNo).process .eq. 'decay') then
-c         call clambdacdDcy(MovedTrack.p,  Pwork, Nproduced)
+         call clambdacDcy(MovedTrack.p,  Pwork, Nproduced)
       elseif(IntInfArray(ProcessNo).process .eq. 'coll') then   
          Nproduced = 0     ! neglect coll.
       else
