@@ -78,6 +78,7 @@ c -------------------------------------tracking a ptcl
 #include  "Zincidentv.h"
 #include  "Zcode.h"
 #include  "Zmanagerp.h"
+#include  "Zstackv.h"
 c                next is for DEBUG
 c//////
 c      logical deb
@@ -182,7 +183,12 @@ c              stack current ptcl
             if(  (MovedTrack.p.code .ge. kpion  .and. 
      *            MovedTrack.p.code .le. knuc ) .or.
      *         MovedTrack.p.code .eq. kgnuc ) then
-               if(IntInfArray(ProcessNo).process .eq. 'coll') then
+c
+c                   from  v6.31 1ry is judged by Stack_pos
+c                  (even if this is not used, almost no problem)
+c                     ! if no stack, the particle should be 1ry (since Zfirst=0)
+               if( Stack_pos .eq. 0 .and.
+     *             IntInfArray(ProcessNo).process .eq. 'coll') then
                   reset = .true.
                else
                   reset = .false.
@@ -194,7 +200,9 @@ c              stack current ptcl
 c             reset minimum time to reach the obs level (time from this
 c             hight to the obs. level), if no mag. exists until
 c                  the first collision point. or ptcl goes streight
-               call cresetTimer(MovedTrack)
+c                  comment out from v6.31
+c               call cresetTimer(MovedTrack)
+
                Zfirst = MovedTrack
             endif
          endif
